import { ExtractorContext } from '../ExtractorContext';
export default class PackageTypingsGenerator {
    private _context;
    private _typeChecker;
    private _indentedWriter;
    /**
     * A cache that tells us the Entry that is tracking a given symbol.  Because of aliases,
     * two different symbols can map to the same Entry object.
     */
    private readonly _entriesBySymbol;
    /**
     * This data structure stores the same entries as _entriesBySymbol.values().
     * They are sorted according to Entry.getSortKey().
     */
    private readonly _entries;
    /**
     * Returns an ancestor of "node", such that the ancestor, any intermediary nodes,
     * and the starting node match a list of expected kinds.  Undefined is returned
     * if there aren't enough ancestors, or if the kinds are incorrect.
     *
     * For example, suppose child "C" has parents A --> B --> C.
     *
     * Calling _matchAncestor(C, [ExportSpecifier, NamedExports, ExportDeclaration])
     * would return A only if A is of kind ExportSpecifier, B is of kind NamedExports,
     * and C is of kind ExportDeclaration.
     *
     * Calling _matchAncestor(C, [ExportDeclaration]) would return C.
     */
    private static _matchAncestor<T>(node, kindsToMatch);
    /**
     * Does a depth-first search of the children of the specified node.  Returns the first child
     * with the specified kind, or undefined if there is no match.
     */
    private static _findFirstChildNode<T>(node, kindToMatch);
    /**
     * For the given symbol, follow imports and type alias to find the symbol that represents
     * the original definition.
     */
    private static _followAliases(symbol, typeChecker);
    /**
     * Helper function for _followAliases(), for handling ts.ExportDeclaration patterns
     */
    private static _followAliasesForExportDeclaration(declaration, symbol);
    /**
     * Helper function for _followAliases(), for handling ts.ImportDeclaration patterns
     */
    private static _followAliasesForImportDeclaration(declaration, symbol);
    private static _getPackagePathFromModuleSpecifier(moduleSpecifier);
    constructor(context: ExtractorContext);
    /**
     * Generates the typings file and writes it to disk.
     *
     * @param dtsFilename    - The *.d.ts output filename
     */
    writeTypingsFile(dtsFilename: string): void;
    generateTypingsFileContent(): string;
    /**
     * Before writing out a declaration, _modifySpan() applies various fixups to make it nice.
     */
    private _modifySpan(rootSpan, entry);
    /**
     * Ensures a unique name for each item in the package typings file.
     */
    private _makeUniqueNames();
    /**
     * Looks up the corresponding Entry for the requested symbol.
     */
    private _getEntryForSymbol(symbol);
    /**
     * Looks up the corresponding Entry for the requested symbol.  If it doesn't exist,
     * then it tries to create one.
     */
    private _fetchEntryForSymbol(symbol);
    private _collectTypes(node);
}
